# def add_car_layers():
#     use_case = "car-sharing"

#     layers = [
#         {
#             "use_case": use_case,
#             "name": "doctype_layer",
#             "properties": [
#                 "UniqueID",
#                 "doctype",
#             ],
#             "cluster_properties": [
#                 "doctype",
#             ]
#         },
#         {
#             "use_case": use_case,
#             "name": "brand_layer",a
#             "properties": [
#                 "UniqueID",
#                 "brand",
#             ],
#             "cluster_properties": [
#                 "brand",
#             ]
#         },
#         {
#             "use_case": use_case,
#             "name": "model_layer",
#             "properties": [
#                 "UniqueID",
#                 "model",
#             ],
#             "cluster_properties": [
#                 "model",
#             ]
#         },
#         {
#             "use_case": use_case,
#             "name": "colour_layer",
#             "properties": [
#                 "UniqueID",
#                 "colour",
#             ],
#             "cluster_properties": [
#                 "colour",
#             ]
#         },
#         {
#             "use_case": use_case,
#             "name": "seats_layer",
#             "properties": [
#                 "UniqueID",
#                 "seats",
#             ],
#             "cluster_properties": [
#                 "seats",
#             ]
#         },
#         {
#             "use_case": use_case,
#             "name": "year_layer",
#             "properties": [
#                 "UniqueID",
#                 "year",
#             ],
#             "cluster_properties": [
#                 "year",
#             ]
#         },
#     ]

#     jwt = TokenManager.getInstance().getToken()

#     for layer in layers:
#         url = f"https://articonf1.itec.aau.at:30420/api/layers"

#         response = requests.post(
#             url,
#             verify=False, 
#             proxies = { "http":None, "https":None },
#             headers = { "Authorization": f"Bearer {jwt}"},
#             json = layer
#         )

#         if response.status_code == 200:
#             print(f"Response: {response.status_code}")
#         else:
#             print(f"Response: {response.status_code}: {response.text}")

import network_constants as nc
from security.token_manager import TokenManager

import requests

def add_table(use_case: str, table_name:str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''
    jwt = TokenManager.getInstance().getToken()

    use_case = "car-sharing"
    columns = [
        # "doctype",
        "carLicensePlate",
        "brand",
        "model",
        "colour",
        "seats",
        "year",
        "ownerId",
        "deleted",
        "state",
        "observations"
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "carLicensePlate"

    
    url = f"https://articonf1.itec.aau.at:30420/api/use-cases/{use_case}/tables"

    table = {
        "name": table_name,
        "mappings": columns
    }

    response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = table
        )

    print(url+": "+str(response.status_code))

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "GeneralCar_layer",
            "properties": [
                "UniqueId",
                "brand",
                "model",
                "colour",
                "seats",
                "year",
                "ownerId",
                "deleted",
                "state"                                
            ],
            "cluster_properties": [
                #TODO discuss with others
                "brand",
                "model",
                "seats",
                "year",
                "ownerId",
                "state"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Owner_layer",
            "properties": [
                "UniqueId",
                "brand",
                "model",
                "colour",
                "seats",
                "year",
                "ownerId",
                "deleted",
                "state"                                
            ],
            "cluster_properties": [
                "OwnerId",
                "UniqueId"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "CarAge_layer",
            "properties": [
                "UniqueId",
                "brand",
                "model",
                "colour",
                "seats",
                "year",
                "ownerId",
                "deleted",
                "state"                                
            ],
            "cluster_properties": [
                #TODO discuss with others
                "year",
                "state"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Model_layer",
            "properties": [
                "UniqueId",
                "brand",
                "model",
                "colour",
                "seats",
                "year",
                "ownerId",
                "deleted",
                "state"                                
            ],
            "cluster_properties": [
                #TODO discuss with others
                "brand",
                "model",
                "seats"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "CarState_layer",
            "properties": [
                "UniqueId",
                "ownerId",
                "deleted",
                "state"                                
            ],
            "cluster_properties": [
                "deleted",
                "state" 
            ]
        }
    ]

    jwt = TokenManager.getInstance().getToken()

    for layer in layers:
        url = f"https://articonf1.itec.aau.at:30420/api/layers"

        response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = layer
        )

    print(url+": "+str(response.status_code))

def main(use_case: str):
    print("CAR")
    table_name = "car"
    add_table(use_case,table_name)
    add_layers(use_case, table_name)