import network_constants as nc
from security.token_manager import TokenManager

import requests

def add_table(use_case: str, table_name: str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''
    jwt = TokenManager.getInstance().getToken()

    # TODO check back with alex

    use_case = "car-sharing"
    columns = [
        # "docType",
        "id",
        "priceForKm",
        "priceForTime",
        "startDate",
        "endDate",
        "deposit",
        # "startPlace",
        # "endPlaces",
        "available",
        "deleted",
        # "cancelledBy",
        "carOwner"
        # "checkedBy",
        # "finishedBy"
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "id"
    columns["carId"] = "car//_id"
    columns["carOwner"] = "car//ownerID"
    ##TODO Question: should i get all the data from the car field? or just the car id/owner?
    columns["startLatitude"] = "startPlace//latitude"
    columns["startLongitude"] = "startPlace//longitude"
    #TODO what if there are more end places? how can i define them? i can only get the first index of the array
    columns["endLatitudeFirst"] = "endPlace[0]//latitude"
    columns["endLongitudeFirst"] = "endPlace[0]//longitude"
    
    url = f"https://articonf1.itec.aau.at:30420/api/use-cases/{use_case}/tables"

    table = {
        "name": table_name,
        "mappings": columns
    }

    response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = table
        )

    print(url+": "+str(response.status_code))

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferStartLocation_layer",
            "properties": [
                "UniqueID",
                "carId",
                "carOwner", 
                "startLatitude",
                "startLongitude",
                "startDate",
                "endFirstLatitude",
                "endFirstLongitude",

            ],
            "cluster_properties": [
                "carOwner",
                "startLatitude",
                "startLongitude"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferEndLocation_layer",
            "properties": [
                "UniqueID",
                "carId",
                "carOwner", 
                "startLatitude",
                "startLongitude",
                "endDate",
                "endFirstLatitude",
                "endFirstLongitude",

            ],
            "cluster_properties": [
                "carOwner",
                "endFirstLatitude",
                "endFirstLongitude"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferedCar_layer",
            "properties": [
                "UniqueID",
                "carId",
                "carOwner"

            ],
            "cluster_properties": [
                "carId",
                "carOwner"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferPrice_layer",
            "properties": [
                "UniqueID",
                "priceForKm",
                "priceForTime",
                "deposit"

            ],
            "cluster_properties": [
                "carOwner",
                "priceForKm",
                "priceForTime",
                "deposit"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferTime_layer",
            "properties": [
                "UniqueID",
                "startDate",
                "endDate"

            ],
            "cluster_properties": [
                "carOwner",
                "startDate",
                "endDate"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "OfferStatus_layer",
            "properties": [
                "UniqueID",
                "available",
                "deleted"

            ],
            "cluster_properties": [
                "carOwner",
                "available",
                "deleted"
            ]
        }
    ]

    jwt = TokenManager.getInstance().getToken()

    for layer in layers:
        url = f"https://articonf1.itec.aau.at:30420/api/layers"

        response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = layer
        )

    print(url+": "+str(response.status_code))

def main(use_case: str):
    print("OFFER")
    table_name = "offer"
    add_table(use_case,table_name)
    add_layers(use_case,table_name)