import network_constants as nc
from security.token_manager import TokenManager

import requests

def add_table(use_case: str, table_name: str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''
    jwt = TokenManager.getInstance().getToken()

    use_case = "car-sharing"
    columns = [
        # "doctype",
        "id"
        "text"
        #"media"
        #"location"
        "user"
        "date"
        #"likesUsers"
        #"reportedBy"
        "deleted"
        "answerTo"
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "id"
    #TODO what if it doesn't have media? i.e the list is empty
    columns["mediaUrlFirst"] = "media[0]//mediaUrl"
    columns["mediaTypeFirst"]= "media[0]//mediaType"
    columns["mediaLabelsFirst"]= "media[0]//mediaLabels"
    columns["latitude"] = "location//latitude"
    columns["longitude"] = "location//longitude"
    #TODO get Likes/reportedBy?
    
    url = f"https://articonf1.itec.aau.at:30420/api/use-cases/{use_case}/tables"

    table = {
        "name": table_name,
        "mappings": columns
    }

    response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = table
        )

    print(url+": "+str(response.status_code))

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationGeneral_layer",
            "properties": [
                "UniqueId",
                "text",
                "user",
                "mediaUrlFirst",
                "mediaTypeFirst",
                "mediaLabelsFirst",
                "latitude",
                "longitude"
                
            ],
            "cluster_properties": [
                #TODO What to add?
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationLocation_layer",
            "properties": [
                "UniqueId",
                "user",
                "latitude",
                "longitude"
                
            ],
            "cluster_properties": [
                "latitude",
                "longitude"  
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationTime_layer",
            "properties": [
                "UniqueId",
                "user",
                "latitude",
                "longitude"
                
            ],
            "cluster_properties": [
                "date"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationUser_layer",
            "properties": [
                "UniqueId",
                "text",
                "user",
                "mediaUrlFirst",
                "mediaTypeFirst",
                "mediaLabelsFirst"
                
            ],
            "cluster_properties": [
                "user"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "PublicationStatus_layer",
            "properties": [
                "UniqueId",
                "text",
                "user",
                "status",
                "answerTo"
                
            ],
            "cluster_properties": [
                "status",
                "answerTo"
            ]
        }
    ]

    jwt = TokenManager.getInstance().getToken()

    for layer in layers:
        url = f"https://articonf1.itec.aau.at:30420/api/layers"

        response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = layer
        )

    print(url+": "+str(response.status_code))

def main(use_case: str):
    print("PUBLICATION")
    table_name = "publication"
    add_table(use_case,table_name)
    add_layers(use_case, table_name)