import network_constants as nc
from security.token_manager import TokenManager

import requests

def add_table(use_case: str, table_name: str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''
    jwt = TokenManager.getInstance().getToken()

    # TODO disscuss with others if it looks ok

    use_case = "car-sharing"
    columns = [
        # "doctype",
        "id",
        "carLicensePlate",
        # "users",
        "offerId",
        # "startPlace",
        # "endPlace",
        "startDate",
        "endDate",
        # "suggestedEndPlaces",
        "rentForTime",
        "seats",
        "totalPrice",
        "observations",
        # "finishedBy",
        "kmTraveled",
        "priceBalance",
        "depositBalance",
        "rewardBalance",
        # "score",
        # "startedBy",
        # "checkedBy",
        "status",
        # "cancelledBy"
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "id"
    columns["user1Id"] = "users[0]//userId"
    columns["user1PassengersNr"] = "users[0]//passengers"
    columns["isDriver"] = "users[0]//isDriver"
    columns["startPlaceLatitude"] = "startPlace//Latitude"
    columns["startPlaceLongitude"] = "startPlace//Latitude"
    columns["endPlaceLatitude"] = "endPlace//Latitude"
    columns["endPlaceLongitude"] = "endPlace//Longitude"
    #TODO consider only the first sugested place? how to consider multiple
    columns["suggestedEndPlace1Latitude"] = "suggestedEndPlaces[0]//endplace//latitude"
    columns["suggestedEndPlace1Longitude"] = "suggestedEndPlaces[0]//endplace//longitude"
    columns["endPlace1User"] = "endPlace[0]//user"
    columns["endPlace1Moment"] = "endPlace[0]//moment"
    columns["endPlace1Latitude"] = "endPlace[0]//coordinate//latitude"
    columns["endPlace1Longitude"] = "endPlace[0]//coordinate//longitude"
    columns["score1User"] = "score[0]//user"
    columns["score1Rating"] = "score[0]//value"
    columns["startedBy1StartPlaceLatitude"] = "startedBy[0]//startPlace//latitude"
    columns["startedBy1StartPlaceLongitude"] = "startedBy[0]//startPlace//longitude"
    columns["startedBy1Moment"] = "startedBy[0]//moment"
    columns["startedBy1User"] = "startedBy[0]//user"
    #TODO CheckedBy,CanceledBy usefull?
    
    url = f"https://articonf1.itec.aau.at:30420/api/use-cases/{use_case}/tables"

    table = {
        "name": table_name,
        "mappings": columns
    }

    response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = table
        )

    print(url+": "+str(response.status_code))

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "User_Layer",
            "properties": [
                'UniqueID',
                'user1Id',                
                'isDriver',
                'score1User',
                'score1Rating',
                'startedBy1User'
            ],
            "cluster_properties": [
                'user1Id'
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "StartingPoint_Layer",
            "properties": [
                'user1Id',
                'UniqueID',
                'startPlaceLatitude',
                'startPlaceLongitude',
                'startDate',
                'endDate'
            ],
            "cluster_properties": [
                'startPlaceLatitude',
                'startPlaceLatitude'
            ]
        },{
            "use_case": use_case,
            "table": table_name,
            "name": "StartingTime_Layer",
            "properties": [
                'user1Id',
                'UniqueID',
                'startDate',
                'endDate',
                'endPlace1Moment',
                'startedBy1Moment'
            ],
            "cluster_properties": [
                'startedBy1Moment',
                'startDate'
            ]
        },{
            "use_case": use_case,
            "table": table_name,
            "name": "Destination_Layer", 
            "properties": [
                'user1Id',
                'UniqueID',
                'endPlace1Latitude',
                'endPlace1Longitude',
                'kmTraveled',
                'startPlaceLatitude',
                'startPlaceLongitude',
            ],
            "cluster_properties": [
                'endPlace1Latitude',
                'endPlace1Longitude'
            ]
        },{
            "use_case": use_case,
            "table": table_name,
            "name": "FinishedTime_Layer", 
            "properties": [
                'user1Id',
                'UniqueID',
                'startDate',
                'endDate',
                'endPlace1Moment',
                'startedBy1Moment'
            ],
            "cluster_properties": [
                'endDate',
                'endPlace1Moment'
            ]
        },{
            "use_case": use_case,
            "table": table_name,
            "name": "Price_Layer",
            "properties": [
                'user1Id',
                'UniqueID',
                'totalPrice',
                'kmTraveled',
                'priceBalance',
                'depositBalance',
                'rewardBalance'
            ],
            "cluster_properties": [
                'totalPrice',
                'kmTraveled',
                'priceBalance',
                'depositBalance',
                'rewardBalance'
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Status_Layer",
            "properties": [
                'UniqueID',
                'user1Id',                
                'status',
                'score1User',
                'score1Rating'
            ],
            "cluster_properties": [
                'status',
                'score1Rating',
                'rentForTime'
            ]
        }
    ]

    jwt = TokenManager.getInstance().getToken()

    for layer in layers:
        url = f"https://articonf1.itec.aau.at:30420/api/layers"

        response = requests.post(
            url,
            verify=False, 
            proxies = { "http":None, "https":None },
            headers = { "Authorization": f"Bearer {jwt}"},
            json = layer
        )

        print(url+": "+str(response.status_code))

def main(use_case: str):
    print("TRAVEL")
    table_name = "travel"
    add_table(use_case,table_name)
    add_layers(use_case, table_name)
